@@ -130,7 +130,7 @@ struct e1inp_ts {
 			/* ip.access driver has one fd for each ts */
 			struct osmo_fd fd;
 			/* ipa keep-alive */
-			struct osmo_fsm_inst* ka_fsm;
+			struct osmo_fsm_inst *ka_fsm;
 		} ipaccess;
 		struct {
 			/* DAHDI driver has one fd for each ts */
@@ -148,12 +148,14 @@ struct e1inp_ts {
 	struct msgb *pending_msg;
 };
 
+#define E1_SUBSLOT_FULL 0xff
+
 struct gsm_e1_subslot {
 	/* Number of E1 link */
 	uint8_t e1_nr;
 	/* Number of E1 TS inside E1 link */
 	uint8_t e1_ts;
-	/* Sub-slot within the E1 TS, 0xff if full TS */
+	/* Sub-slot within the E1 TS, 0xff (E1_SUBSLOT_FULL) if full TS */
 	uint8_t e1_ts_ss;
 };
 
@@ -164,6 +166,17 @@ enum e1inp_line_role {
 	E1INP_LINE_R_MAX
 };
 
+/* Notes on setting/getting Sa bits (TABLE 5A and 5B of ITU-T G.704)
+ * The sa_bits byte contains the Sa bits in TS 0, if multi frame is used:
+ * bit 7 = Sa8, bit 6 = Sa7, bit 5 = Sa5, bit 4 = Sa4, bit 3 = Sa64, bit 2 = Sa63, bit 1 = Sa62, bit 0 = Sa61.
+ * The sa_bits byte contains the Sa bits in TS 0, if double frame is used:
+ * bit 7 = Sa8, bit 6 = Sa7, bit 5 = Sa5, bit 4 = Sa4, bit 0 = Sa6.
+ * The received Sa bits are reported whenever they change (and are stable for some frames, depending on the
+ * implementation).  Before any report, all Sa bits are assumed to be set to 1.
+ * Setting sa_bits byte will change the transmitted Sa bits on TS0.
+ * Before setting them, all Sa bits are transmitted as 1.
+ */
+
 struct e1inp_driver {
 	struct llist_head list;
 	const char *name;
@@ -174,6 +187,12 @@ struct e1inp_driver {
 	int default_delay;
 	int has_keepalive;
 	const char *bind_addr;
+
+	/* Set Sa bits to transmit in TS0 (MSB to LSB): Sa8 Sa7 Sa5 Sa4 Sa64 Sa63 Sa62 Sa61/Sa6 */
+	int (*set_sa_bits)(struct e1inp_line *line, uint8_t sa_bits);
+
+	/* Optional callback to perform driver specific initialization when the line is created. */
+	int (*line_create)(struct e1inp_line *line);
 };
 
 struct e1inp_line_ops {
@@ -242,6 +261,15 @@ enum e1inp_signal_input {
 	S_L_INP_LINE_INIT,
 	S_L_INP_LINE_ALARM,
 	S_L_INP_LINE_NOALARM,
+	S_L_INP_LINE_LOS,
+	S_L_INP_LINE_NOLOS,
+	S_L_INP_LINE_AIS,
+	S_L_INP_LINE_NOAIS,
+	S_L_INP_LINE_RAI,
+	S_L_INP_LINE_NORAI,
+	S_L_INP_LINE_SLIP_RX,
+	S_L_INP_LINE_SLIP_TX,
+	S_L_INP_LINE_SA_BITS,
 };
 
 extern const struct value_string e1inp_signal_names[];
@@ -303,6 +331,15 @@ int e1inp_ts_config_hdlc(struct e1inp_ts *ts, struct e1inp_line *line,
 			 void (*hdlc_recv_cb)(struct e1inp_ts *ts,
 					      struct msgb *msg));
 
+/* configure and initialize one timeslot dedicated to nothing */
+int e1inp_ts_config_none(struct e1inp_ts *ts, struct e1inp_line *line);
+
+/*
+ * configure Sa bits on TS0, if supported by driver (TABLE 5A and 5B of ITU-T G.704)
+ * sa_bits (MSB to LSB): Sa8 Sa7 Sa5 Sa4 Sa64 Sa63 Sa62 Sa61/Sa6
+ */
+int e1inp_ts_set_sa_bits(struct e1inp_line *line, uint8_t sa_bits);
+
 /* obtain a string identifier/name for the given timeslot */
 void e1inp_ts_name(char *out, size_t out_len, const struct e1inp_ts *ts);
 
@@ -358,6 +395,8 @@ struct input_signal_data {
 	uint8_t tei;
 	uint8_t sapi;
 	uint8_t ts_nr;
+	/* received Sa bits in TS0 (MSB to LSB): Sa8 Sa7 Sa5 Sa4 Sa64 Sa63 Sa62 Sa61/Sa6 */
+	uint8_t sa_bits;
 	struct gsm_bts_trx *trx;
 	struct e1inp_line *line;
 };
