@@ -1,5 +1,5 @@
 /* E1 vty interface */
-/* (C) 2011 by Harald Welte <laforge@gnumonks.org>
+/* (C) 2011-2021 by Harald Welte <laforge@gnumonks.org>
  * All Rights Reserved
  *
  * SPDX-License-Identifier: AGPL-3.0+
@@ -245,33 +245,87 @@ DEFUN_ATTR(cfg_e1line_name, cfg_e1_line_name_cmd,
 	return CMD_SUCCESS;
 }
 
-DEFUN_ATTR(cfg_e1_pcap, cfg_e1_pcap_cmd,
-	   "pcap .FILE",
-	   "Setup a pcap recording of all E1 traffic\n"
+DEFUN_ATTR(cfg_e1line_connect_timeout, cfg_e1_line_connect_timeout_cmd,
+	   "e1_line <0-255> connect-timeout <0-60>",
+	   E1_LINE_HELP "Set connect timeout\n" "Connect timeout in seconds (0 to disable)\n",
+	   CMD_ATTR_IMMEDIATE)
+{
+	struct e1inp_line *line;
+	int e1_nr = atoi(argv[0]);
+	unsigned int timeout = atoi(argv[1]);
+
+	line = e1inp_line_find(e1_nr);
+	if (!line) {
+		vty_out(vty, "%% Line %d doesn't exist%s", e1_nr, VTY_NEWLINE);
+		return CMD_WARNING;
+	}
+	line->connect_timeout = timeout;
+
+	return CMD_SUCCESS;
+}
+
+
+DEFUN_ATTR(cfg_e1line_pcap, cfg_e1line_pcap_cmd,
+	   "e1_line <0-255> pcap .FILE",
+	   E1_LINE_HELP "Setup a pcap recording of E1 traffic for line\n"
 	   "Filename to save the packets to\n", CMD_ATTR_IMMEDIATE)
 {
+	struct e1inp_line *line;
 	int fd;
+	int rc;
+	int e1_nr = atoi(argv[0]);
 
-	fd = open(argv[0], O_WRONLY | O_CREAT | O_TRUNC, 0660);
-	if (fd < 0) {
-		vty_out(vty, "Failed to setup E1 pcap recording to %s.%s", argv[0], VTY_NEWLINE);
+	line = e1inp_line_find(e1_nr);
+	if (!line) {
+		vty_out(vty, "%% Line %d doesn't exist%s", e1_nr, VTY_NEWLINE);
 		return CMD_WARNING;
 	}
 
-	e1_set_pcap_fd(fd);
+	fd = open(argv[1], O_WRONLY | O_CREAT | O_TRUNC, 0660);
+	if (fd < 0) {
+		vty_out(vty, "Failed to setup E1 pcap recording to %s%s", argv[1], VTY_NEWLINE);
+		return CMD_WARNING;
+	}
 
+	rc = e1_set_pcap_fd2(line, fd);
+	if (rc < 0) {
+		vty_out(vty, "Failed to write to E1 pcap file %s%s", argv[1], VTY_NEWLINE);
+		close(fd);
+		return CMD_WARNING;
+	}
+
+	osmo_talloc_replace_string(line, &line->pcap_file, argv[1]);
 	return CMD_SUCCESS;
 }
 
-DEFUN_ATTR(cfg_e1_no_pcap, cfg_e1_no_pcap_cmd,
-	   "no pcap",
-	   NO_STR "Disable pcap recording of all E1 traffic\n",
+DEFUN_ATTR(cfg_e1line_no_pcap, cfg_e1line_no_pcap_cmd,
+	   "no e1_line <0-255> pcap",
+	   NO_STR E1_LINE_HELP "Disable pcap recording of E1 traffic for line\n",
 	   CMD_ATTR_IMMEDIATE)
 {
-	e1_set_pcap_fd(-1);
+	struct e1inp_line *line;
+	int e1_nr = atoi(argv[0]);
+	line = e1inp_line_find(e1_nr);
+
+	e1_set_pcap_fd2(line, -1);
+	if (line->pcap_file) {
+		talloc_free(line->pcap_file);
+		line->pcap_file = NULL;
+	}
 	return CMD_SUCCESS;
 }
 
+DEFUN_DEPRECATED(cfg_e1_pcap_deprec, cfg_e1_pcap_deprec_cmd,
+	     "pcap .FILE", "Legacy")
+{
+	vty_out(vty, "%% 'pcap' is deprecated and has no effect: use e1_line <0-255> pcap%s",
+		VTY_NEWLINE);
+	return CMD_WARNING;
+}
+
+ALIAS_DEPRECATED(cfg_e1_pcap_deprec, cfg_e1_pcap_deprec_no_cmd,
+	     "no pcap", NO_STR);
+
 DEFUN_ATTR(cfg_e1inp, cfg_e1inp_cmd,
 	   "e1_input",
 	   "Configure E1/T1/J1 TDM input\n", CMD_ATTR_IMMEDIATE)
@@ -293,6 +347,38 @@ DEFUN_USRATTR(cfg_ipa_bind,
 	return CMD_SUCCESS;
 }
 
+DEFUN_USRATTR(cfg_ipa_dscp, cfg_ipa_dscp_cmd,
+	      X(OSMO_ABIS_LIB_ATTR_IPA_NEW_LNK),
+	      "ipa ip-dscp (oml|rsl) <0-63>",
+	      "ipa driver config\n"
+	      "Set IP DSCP value for outbound packets\n"
+	      "Set IP DSCP for OML link\n"
+	      "Set IP DSCP for RSL link\n"
+	      "IP DSCP Value to use\n")
+{
+	if (!strcmp(argv[0], "oml"))
+		g_e1inp_ipaccess_pars.oml.dscp = atoi(argv[1]);
+	else
+		g_e1inp_ipaccess_pars.rsl.dscp = atoi(argv[1]);
+	return CMD_SUCCESS;
+}
+
+DEFUN_USRATTR(cfg_ipa_priority, cfg_ipa_priority_cmd,
+	      X(OSMO_ABIS_LIB_ATTR_IPA_NEW_LNK),
+	      "ipa socket-priority (oml|rsl) <0-255>",
+	      "ipa driver config\n"
+	      "Set socket priority value for outbound packets\n"
+	      "Set socket priority for OML link\n"
+	      "Set socket priority for RSL link\n"
+	      "socket priority value to use (>6 requires CAP_NET_ADMIN)\n")
+{
+	if (!strcmp(argv[0], "oml"))
+		g_e1inp_ipaccess_pars.oml.priority = atoi(argv[1]);
+	else
+		g_e1inp_ipaccess_pars.rsl.priority = atoi(argv[1]);
+	return CMD_SUCCESS;
+}
+
 static int e1inp_config_write(struct vty *vty)
 {
 	struct e1inp_line *line;
@@ -310,15 +396,15 @@ static int e1inp_config_write(struct vty *vty)
 		if (line->name)
 			vty_out(vty, " e1_line %u name %s%s", line->num,
 				line->name, VTY_NEWLINE);
+		if (line->connect_timeout != 0)
+			vty_out(vty, " e1_line %u connect-timeout %u%s", line->num, line->connect_timeout,
+				VTY_NEWLINE);
 		if (!line->keepalive_num_probes)
 			vty_out(vty, " no e1_line %u keepalive%s", line->num,
 				VTY_NEWLINE);
-		else if (line->keepalive_idle_timeout == E1INP_USE_DEFAULT &&
-			 line->keepalive_num_probes == E1INP_USE_DEFAULT &&
-			 line->keepalive_probe_interval == E1INP_USE_DEFAULT)
-			vty_out(vty, " e1_line %u keepalive%s", line->num,
-				VTY_NEWLINE);
-		else
+		else if (line->keepalive_idle_timeout != E1INP_USE_DEFAULT ||
+			 line->keepalive_num_probes != E1INP_USE_DEFAULT ||
+			 line->keepalive_probe_interval != E1INP_USE_DEFAULT)
 			vty_out(vty, " e1_line %u keepalive %d %d %d%s",
 				line->num,
 				line->keepalive_idle_timeout,
@@ -329,6 +415,9 @@ static int e1inp_config_write(struct vty *vty)
 			vty_out(vty, " e1_line %u ipa-keepalive %d %d%s", line->num,
 				line->ipa_kap->interval, line->ipa_kap->wait_for_resp,
 				VTY_NEWLINE);
+		if (line->pcap_file)
+			vty_out(vty, " e1_line %u pcap %s%s", line->num,
+				line->pcap_file, VTY_NEWLINE);
 	}
 
 	const char *ipa_bind = e1inp_ipa_get_bind_addr();
@@ -336,6 +425,15 @@ static int e1inp_config_write(struct vty *vty)
 		vty_out(vty, " ipa bind %s%s",
 			ipa_bind, VTY_NEWLINE);
 
+	if (g_e1inp_ipaccess_pars.oml.dscp)
+		vty_out(vty, " ipa ip-dscp oml %u%s", g_e1inp_ipaccess_pars.oml.dscp, VTY_NEWLINE);
+	if (g_e1inp_ipaccess_pars.rsl.dscp)
+		vty_out(vty, " ipa ip-dscp rsl %u%s", g_e1inp_ipaccess_pars.rsl.dscp, VTY_NEWLINE);
+	if (g_e1inp_ipaccess_pars.oml.priority)
+		vty_out(vty, " ipa socket-priority oml %u%s", g_e1inp_ipaccess_pars.oml.priority, VTY_NEWLINE);
+	if (g_e1inp_ipaccess_pars.rsl.priority)
+		vty_out(vty, " ipa socket-priority rsl %u%s", g_e1inp_ipaccess_pars.rsl.priority, VTY_NEWLINE);
+
 	return CMD_SUCCESS;
 }
 
@@ -365,6 +463,8 @@ static void e1line_dump_vty(struct vty *vty, struct e1inp_line *line,
 	vty_out(vty, "E1 Line Number %u, Name %s, Driver %s%s",
 		line->num, line->name ? line->name : "",
 		line->driver->name, VTY_NEWLINE);
+	if (line->pcap_file)
+		vty_out(vty, "PCAP %s%s", line->pcap_file, VTY_NEWLINE);
 	if (line->driver->vty_show)
 		line->driver->vty_show(vty, line);
 	if (stats)
@@ -373,7 +473,7 @@ static void e1line_dump_vty(struct vty *vty, struct e1inp_line *line,
 
 DEFUN(show_e1line,
       show_e1line_cmd,
-      "show e1_line [line_nr] [stats]",
+      "show e1_line [<0-255>] [stats]",
 	SHOW_STR "Display information about a E1 line\n"
 	"E1 Line Number\n" "Include statistics\n")
 {
@@ -407,13 +507,13 @@ static void e1ts_dump_vty(struct vty *vty, struct e1inp_ts *ts)
 	if (ts->type == E1INP_TS_TYPE_NONE)
 		return;
 	vty_out(vty, "E1 Timeslot %2u of Line %u is Type %s%s",
-		ts->num, ts->line->num, e1inp_tstype_name(ts->type),
+		ts->num-1, ts->line->num, e1inp_tstype_name(ts->type),
 		VTY_NEWLINE);
 }
 
 DEFUN(show_e1ts,
       show_e1ts_cmd,
-      "show e1_timeslot [line_nr] [ts_nr]",
+      "show e1_timeslot [<0-255>] [<0-31>]",
 	SHOW_STR "Display information about a E1 timeslot\n"
 	"E1 Line Number\n" "E1 Timeslot Number\n")
 {
@@ -477,13 +577,16 @@ int e1inp_vty_init(void)
 	install_lib_element(CONFIG_NODE, &cfg_e1inp_cmd);
 	install_node(&e1inp_node, e1inp_config_write);
 
-	install_lib_element(L_E1INP_NODE, &cfg_e1_pcap_cmd);
-	install_lib_element(L_E1INP_NODE, &cfg_e1_no_pcap_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_e1line_pcap_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_e1line_no_pcap_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_e1_pcap_deprec_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_e1_pcap_deprec_no_cmd);
 
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_driver_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_port_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_socket_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_name_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_e1_line_connect_timeout_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_keepalive_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_keepalive_params_cmd);
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_no_keepalive_cmd);
@@ -491,6 +594,8 @@ int e1inp_vty_init(void)
 	install_lib_element(L_E1INP_NODE, &cfg_e1_line_no_ipa_keepalive_cmd);
 
 	install_lib_element(L_E1INP_NODE, &cfg_ipa_bind_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_ipa_dscp_cmd);
+	install_lib_element(L_E1INP_NODE, &cfg_ipa_priority_cmd);
 
 	install_lib_element_ve(&show_e1drv_cmd);
 	install_lib_element_ve(&show_e1line_cmd);
